@@ -2,9 +2,10 @@ package WebService::Avalara::AvaTax;
 
 # ABSTRACT: Avalara SOAP interface as compiled Perl methods
 
-use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
+use strict;
+use warnings;
 
-our $VERSION = '0.018';     # VERSION
+our $VERSION = '0.019';    # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -19,7 +20,7 @@ use utf8;
 #pod =head1 DESCRIPTION
 #pod
 #pod This class provides a Perl method API for
-#pod L<Avalara AvaTax|http://developer.avalara.com/api-docs/soap>
+#pod Avalara AvaTax (C<http://developer.avalara.com/api-docs/soap>)
 #pod web services. The first call to any AvaTax SOAP operation uses
 #pod L<XML::Compile::WSDL11|XML::Compile::WSDL11>
 #pod to compile and execute against the specified Avalara AvaTax service;
@@ -67,6 +68,8 @@ with 'WebService::Avalara::AvaTax::Role::Connection';
 #pod
 #pod =item L<password|WebService::Avalara::AvaTax::Role::Connection/password>
 #pod
+#pod =item L<use_wss|WebService::Avalara::AvaTax::Role::Connection/use_wss>
+#pod
 #pod =item L<is_production|WebService::Avalara::AvaTax::Role::Connection/is_production>
 #pod
 #pod =item L<user_agent|WebService::Avalara::AvaTax::Role::Connection/user_agent>
@@ -91,7 +94,7 @@ sub _new_service {
     my $class = __PACKAGE__ . '::Service::' . shift;
     return $class->new(
         map { ( $_ => $self->$_ ) }
-            qw(username password is_production user_agent debug),
+            qw(username password use_wss is_production user_agent debug),
     );
 }
 
@@ -101,8 +104,7 @@ sub _new_service {
 #pod other attributes and methods consumed from
 #pod L<WebService::Avalara::AvaTax::Role::Connection|WebService::Avalara::AvaTax::Role::Connection>,
 #pod available method names are dynamically loaded from each
-#pod L</services>'
-#pod L<wsdl|WebService::Avalara::AvaTax::Role::Connection/wsdl>
+#pod L</services>' C<wsdl>
 #pod attribute and can be passed either a hash or reference to a hash with the
 #pod necessary parameters. In scalar context they return a reference to a hash
 #pod containing the results of the SOAP call; in list context they return the
@@ -113,7 +115,7 @@ sub _new_service {
 #pod If there is no result then you should check the trace object for why.
 #pod
 #pod Please consult the
-#pod L<Avalara SOAP API reference|http://developer.avalara.com/api-reference>
+#pod Avalara SOAP API reference (C<http://developer.avalara.com/api-reference>)
 #pod for semantic details on the methods, parameters and results available for each
 #pod of the methods listed below. Note that in order to make this interface easier
 #pod and more Perl-ish, the following changes have been made:
@@ -166,22 +168,18 @@ sub BUILD {
     my $self = shift;
 
     for my $service ( @{ $self->services } ) {
-        my %soap_params = map { ( $_ => $service->$_ ) } qw(port service);
-
-        $service->wsdl->compileCalls(
-            transport => $service->_transport,
-            %soap_params,
-        );
-        for my $operation ( $service->wsdl->operations(%soap_params) ) {
-            my $method_name = $operation->name;
+        while ( my ( $operation_name, $client )
+            = each %{ $service->clients } )
+        {
+            my $method_name = $operation_name;
             if ( not $self->orthodox ) {    # normalize operation name
                 $method_name
                     =~ s/ (?<= [[:alnum:]] ) ( [[:upper:]] ) /_\l$1/xmsg;
                 $method_name = lcfirst $method_name;
             }
 
-            $self->_stash->add_symbol(
-                "&$method_name" => _method_closure( $service, $operation ) );
+            $self->_stash->add_symbol( "&$method_name" =>
+                    _method_closure( $service, $operation_name, $client ) );
         }
     }
     return;
@@ -212,35 +210,43 @@ const my %OPERATION_PARAMETER => (
 );
 
 sub _method_closure {
-    my ( $service, $operation ) = @_;
+    my ( $service, $operation_name, $client ) = @_;
     return sub {
         my ( $self, @parameters ) = @_;
 
-        my $wsdl = $service->wsdl;
-        $service->_current_operation_name( $operation->name );
-
-        if ( 'GetTax' eq $operation ) {
+        $service->_current_operation_name($operation_name);
+        if ( 'GetTax' eq $operation_name ) {
             @parameters = _today_to_docdate(@parameters);
         }
 
-        my ( $answer_ref, $trace ) = $wsdl->call(
-            $operation->name => {
-                Profile => {
-                    Client => "$PROGRAM_NAME," . ( $main::VERSION // q{} ),
-                    Adapter => __PACKAGE__ . q{,} . ( $VERSION // q{} ),
-                    Machine => hostname(),
-                },
-                parameters => {
-                    $OPERATION_PARAMETER{ $operation->name } =>
-                        @parameters % 2
-                    ? "@parameters"
-                    : {@parameters},
-                },
+        my $client_version  = "$PROGRAM_NAME,";
+        my $adapter_version = __PACKAGE__ . q{,};
+        if ($main::VERSION) { $client_version  .= $main::VERSION }
+        if ($VERSION)       { $adapter_version .= $VERSION }
+        my ( $answer_ref, $trace ) = $client->(
+            Profile => {
+                Client  => $client_version,
+                Adapter => $adapter_version,
+                Machine => hostname(),
             },
+            parameters => {
+                $OPERATION_PARAMETER{$operation_name} => @parameters % 2
+                ? "@parameters"
+                : {@parameters},
+            },
+            $service->use_wss ? ()
+            : ( Security => {
+                    UsernameToken => {
+                        map { ( "\u$_" => $service->$_ ) }
+                            qw(username password),
+                    },
+                },
+            ),
         );
         if ( 'HASH' eq ref $answer_ref ) {
+            ## no critic (ValuesAndExpressions::ProhibitAccessOfPrivateData)
             $answer_ref
-                = $answer_ref->{parameters}{ $operation->name . 'Result' };
+                = $answer_ref->{parameters}{"${operation_name}Result"};
         }
         return wantarray ? ( $answer_ref, $trace ) : $answer_ref;
     };
@@ -262,8 +268,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Mark Gardner ZipRecruiter cpan testmatrix url annocpan anno bugtracker rt
 cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -273,7 +277,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -287,7 +291,7 @@ version 0.018
 =head1 DESCRIPTION
 
 This class provides a Perl method API for
-L<Avalara AvaTax|http://developer.avalara.com/api-docs/soap>
+Avalara AvaTax (C<http://developer.avalara.com/api-docs/soap>)
 web services. The first call to any AvaTax SOAP operation uses
 L<XML::Compile::WSDL11|XML::Compile::WSDL11>
 to compile and execute against the specified Avalara AvaTax service;
@@ -299,8 +303,7 @@ Aside from the L</new> method, L</services> attribute and
 other attributes and methods consumed from
 L<WebService::Avalara::AvaTax::Role::Connection|WebService::Avalara::AvaTax::Role::Connection>,
 available method names are dynamically loaded from each
-L</services>'
-L<wsdl|WebService::Avalara::AvaTax::Role::Connection/wsdl>
+L</services>' C<wsdl>
 attribute and can be passed either a hash or reference to a hash with the
 necessary parameters. In scalar context they return a reference to a hash
 containing the results of the SOAP call; in list context they return the
@@ -311,7 +314,7 @@ object suitable for debugging and exception handling.
 If there is no result then you should check the trace object for why.
 
 Please consult the
-L<Avalara SOAP API reference|http://developer.avalara.com/api-reference>
+Avalara SOAP API reference (C<http://developer.avalara.com/api-reference>)
 for semantic details on the methods, parameters and results available for each
 of the methods listed below. Note that in order to make this interface easier
 and more Perl-ish, the following changes have been made:
@@ -641,9 +644,7 @@ provide C<IsAuthorized> operations. However, since the latter is loaded last,
 only its version is called when you call this method. If you need to
 specifically call a particular service's C<IsAuthorized>, use the
 L<call|XML::Compile::WSDL11/Compilers>
-method on its
-L<wsdl|WebService::Avalara::AvaTax::Role::Connection/wsdl>
-attribute.
+method on its C<wsdl> attribute.
 
 Note that the parameter passed to this call is a comma-delimited list of
 SOAP operation names in C<CamelCase>, not C<lowercase_with_underscores>.
@@ -675,9 +676,7 @@ provide C<Ping> operations. However, since the latter is loaded last,
 only its version is called when you call this method. If you need to
 specifically call a particular service's C<Ping>, use the
 L<call|XML::Compile::WSDL11/Compilers>
-method on its
-L<wsdl|WebService::Avalara::AvaTax::Role::Connection/wsdl>
-attribute.
+method on its C<wsdl> attribute.
 
 Note that this method does support a single string as a message parameter;
 this is effectively ignored though.
@@ -709,7 +708,8 @@ Example:
 
 I<< (SOAP operation: C<ApplyPayment>) >>
 
-From L<Avalara API documentation|http://developer.avalara.com/api-docs/soap/applypayment>:
+From Avalara API documentation
+(C<http://developer.avalara.com/api-docs/soap/applypayment>):
 
 =over
 
@@ -735,7 +735,8 @@ Example:
 
 I<< (SOAP operation: C<ReconcileTaxHistory>) >>
 
-From L<Avalara API documentation|http://developer.avalara.com/api-docs/soap/reconciletaxhistory>:
+From Avalara API documentation
+(C<http://developer.avalara.com/api-docs/soap/reconciletaxhistory>):
 
 =over
 
@@ -745,7 +746,8 @@ pull a range of documents for reconciliation against a document of record
 flagged documents would then be omitted from subsequent ReconcileTaxHistory
 calls. This method no longer changes the "reconciled" document flag, but can
 be used to retrieve ranges of document data (much like the AccountSvc
-L<DocumentFetch|http://developer.avalara.com/api-docs/soap/accountsvc/document-elements>),
+DocumentFetch
+(C<http://developer.avalara.com/api-docs/soap/accountsvc/document-elements>)),
 and remains in the TaxSvc WSDL and some automatically built
 adaptors for backwards compatibility.
 
@@ -783,6 +785,8 @@ passed to both:
 
 =item L<password|WebService::Avalara::AvaTax::Role::Connection/password>
 
+=item L<use_wss|WebService::Avalara::AvaTax::Role::Connection/use_wss>
+
 =item L<is_production|WebService::Avalara::AvaTax::Role::Connection/is_production>
 
 =item L<user_agent|WebService::Avalara::AvaTax::Role::Connection/user_agent>
@@ -802,7 +806,7 @@ their C<CamelCase> SOAP operation names.
 
 =over
 
-=item L<Avalara Developer Network|http://developer.avalara.com/>
+=item Avalara Developer Network (C<http://developer.avalara.com/>)
 
 Official source for Avalara developer information, including API
 references, technical articles and more.
@@ -932,7 +936,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by ZipRecruiter.
+This software is copyright (c) 2016 by ZipRecruiter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
