@@ -2,9 +2,10 @@ package WebService::Avalara::AvaTax::Role::Connection;
 
 # ABSTRACT: Common attributes and methods for AvaTax
 
-use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
+use strict;
+use warnings;
 
-our $VERSION = '0.018';     # VERSION
+our $VERSION = '0.019';    # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -15,7 +16,7 @@ use utf8;
 #pod =head1 DESCRIPTION
 #pod
 #pod This role factors out the common attributes and methods used by the
-#pod L<Avalara AvaTax|http://developer.avalara.com/api-docs/soap>
+#pod Avalara AvaTax (C<http://developer.avalara.com/api-docs/soap>)
 #pod web service interface.
 #pod
 #pod =cut
@@ -24,24 +25,17 @@ use Log::Report;
 use LWP::UserAgent;
 use LWPx::UserAgent::Cached;
 use Moo::Role;
-use MooX::Types::MooseLike::Email 'EmailAddressLoose';
 use Mozilla::CA;
 use Types::Standard qw(Bool InstanceOf Str);
-use Types::URI 'Uri';
-use URI;
-use XML::Compile::SOAP::WSS;
-use XML::Compile::Transport::SOAPHTTP;
-use XML::Compile::WSDL11;
-use XML::Compile::WSS;
 use namespace::clean;
 
 #pod =attr username
 #pod
-#pod The Avalara email address used for authentication. Required.
+#pod The Avalara AvaTax Admin Console user name. Usually an email address. Required.
 #pod
 #pod =cut
 
-has username => ( is => 'ro', isa => EmailAddressLoose, required => 1 );
+has username => ( is => 'ro', isa => Str, required => 1 );
 
 #pod =attr password
 #pod
@@ -51,6 +45,17 @@ has username => ( is => 'ro', isa => EmailAddressLoose, required => 1 );
 
 has password => ( is => 'ro', isa => Str, required => 1 );
 
+#pod =attr use_wss
+#pod
+#pod A boolean value that indicates whether or not to use WSS security tokens in
+#pod the SOAP header or to use those specified in Avalara's alternate security WSDL.
+#pod Defaults to true. Normally you should leave this alone unless your application
+#pod does not work correctly with WSS.
+#pod
+#pod =cut
+
+has use_wss => ( is => 'rwp', isa => Bool, default => 1 );
+
 #pod =attr is_production
 #pod
 #pod A boolean value that indicates whether to connect to the production AvaTax
@@ -60,36 +65,6 @@ has password => ( is => 'ro', isa => Str, required => 1 );
 
 has is_production => ( is => 'ro', isa => Bool, default => 0 );
 
-#pod =attr uri
-#pod
-#pod The L<URI|URI> of the WSDL file used to define the web service.
-#pod Consumer classes are expected to set this attribute.
-#pod As a convenience this can also be set with anything that
-#pod L<Types::URI|Types::URI> can coerce into a C<Uri>.
-#pod
-#pod =cut
-
-has uri => ( is => 'lazy', isa => Uri, coerce => 1 );
-
-#pod =attr port
-#pod
-#pod The SOAP port identifier (not to be confused with the TCP/IP port) used in the
-#pod WSDL file at L</uri>.
-#pod Consumer classes are expected to set this attribute.
-#pod
-#pod =cut
-
-has port => ( is => 'ro', isa => Str );
-
-#pod =attr service
-#pod
-#pod The SOAP service name used in the WSDL file at L</uri>.
-#pod Consumer classes are expected to set this attribute.
-#pod
-#pod =cut
-
-has service => ( is => 'ro', isa => Str );
-
 #pod =attr debug
 #pod
 #pod When set to true, the L<Log::Report|Log::Report> dispatcher used by
@@ -129,94 +104,12 @@ has user_agent => (
     default => sub { LWPx::UserAgent::Cached->new },
 );
 
-#pod =attr wsdl
-#pod
-#pod After construction, you can retrieve the created
-#pod L<XML::Compile::WSDL11|XML::Compile::WSDL11> instance.
-#pod
-#pod Example:
-#pod
-#pod     my $wsdl = $avatax->wsdl;
-#pod     my @soap_operations = map { $_->name } $wsdl->operations;
-#pod
-#pod =cut
-
-has wsdl => (
-    is       => 'lazy',
-    isa      => InstanceOf ['XML::Compile::WSDL11'],
-    init_arg => undef,
-    default  => sub {
-        XML::Compile::WSDL11->new(
-            $_[0]->user_agent->get( $_[0]->uri )->content );
-    },
-);
-
-has _wss => (
-    is       => 'ro',
-    isa      => InstanceOf ['XML::Compile::SOAP::WSS'],
-    default  => sub { XML::Compile::SOAP::WSS->new },
-    init_arg => undef,
-);
-
-has _auth => (
-    is       => 'lazy',
-    isa      => InstanceOf ['XML::Compile::WSS'],
-    init_arg => undef,
-);
-
-sub _build__auth {
-    my $self = shift;
-    my $wss  = $self->_wss;
-    return $wss->basicAuth( map { ( $_ => $self->$_ ) }
-            qw(username password) );
-}
-
-has _current_operation_name => ( is => 'rw', isa => Str, default => q{} );
-
-has _transport => (
-    is       => 'lazy',
-    isa      => InstanceOf ['XML::Compile::Transport::SOAPHTTP'],
-    init_arg => undef,
-);
-
-sub _build__transport {
-    my $self = shift;
-
-    my $wss  = $self->_wss;
-    my $wsdl = $self->wsdl;
-    my $auth = $self->_auth;
-
-    my %soap_params  = map { ( $_ => $self->$_ ) } qw(port service);
-    my $endpoint_uri = URI->new( $wsdl->endPoint(%soap_params) );
-    my $user_agent   = $self->user_agent;
-
-    $user_agent->add_handler(
-        request_prepare => sub {
-            $_[0]->header(
-                SOAPAction =>
-                    $wsdl->operation( $self->_current_operation_name,
-                    %soap_params )->soapAction,
-            );
-        },
-        (   m_method => 'POST',
-            map { ( "m_$_" => $endpoint_uri->$_ ) } qw(scheme host_port path),
-        ),
-    );
-
-    return XML::Compile::Transport::SOAPHTTP->new(
-        address    => $endpoint_uri,
-        user_agent => $user_agent,
-    );
-}
-
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Mark Gardner ZipRecruiter cpan testmatrix url annocpan anno bugtracker rt
 cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -226,7 +119,7 @@ WebService::Avalara::AvaTax::Role::Connection - Common attributes and methods fo
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -236,42 +129,31 @@ version 0.018
 =head1 DESCRIPTION
 
 This role factors out the common attributes and methods used by the
-L<Avalara AvaTax|http://developer.avalara.com/api-docs/soap>
+Avalara AvaTax (C<http://developer.avalara.com/api-docs/soap>)
 web service interface.
 
 =head1 ATTRIBUTES
 
 =head2 username
 
-The Avalara email address used for authentication. Required.
+The Avalara AvaTax Admin Console user name. Usually an email address. Required.
 
 =head2 password
 
 The password used for Avalara authentication. Required.
 
+=head2 use_wss
+
+A boolean value that indicates whether or not to use WSS security tokens in
+the SOAP header or to use those specified in Avalara's alternate security WSDL.
+Defaults to true. Normally you should leave this alone unless your application
+does not work correctly with WSS.
+
 =head2 is_production
 
 A boolean value that indicates whether to connect to the production AvaTax
 services (true) or development (false). Defaults to false.
 
-=head2 uri
-
-The L<URI|URI> of the WSDL file used to define the web service.
-Consumer classes are expected to set this attribute.
-As a convenience this can also be set with anything that
-L<Types::URI|Types::URI> can coerce into a C<Uri>.
-
-=head2 port
-
-The SOAP port identifier (not to be confused with the TCP/IP port) used in the
-WSDL file at L</uri>.
-Consumer classes are expected to set this attribute.
-
-=head2 service
-
-The SOAP service name used in the WSDL file at L</uri>.
-Consumer classes are expected to set this attribute.
-
 =head2 debug
 
 When set to true, the L<Log::Report|Log::Report> dispatcher used by
@@ -288,16 +170,6 @@ the C<HTTPS_CA_FILE> environment variable to the result from
 L<Mozilla::CA::SSL_ca_file|Mozilla::CA> in order to correctly
 resolve certificate names.
 
-=head2 wsdl
-
-After construction, you can retrieve the created
-L<XML::Compile::WSDL11|XML::Compile::WSDL11> instance.
-
-Example:
-
-    my $wsdl = $avatax->wsdl;
-    my @soap_operations = map { $_->name } $wsdl->operations;
-
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -411,7 +283,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by ZipRecruiter.
+This software is copyright (c) 2016 by ZipRecruiter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
