@@ -2,9 +2,10 @@ package WebService::Avalara::AvaTax::Service::Tax;
 
 # ABSTRACT: Avalara AvaTax tax engine service via SOAP
 
-use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
+use strict;
+use warnings;
 
-our $VERSION = '0.018';     # VERSION
+our $VERSION = '0.019';    # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -20,36 +21,48 @@ use utf8;
 #pod =head1 DESCRIPTION
 #pod
 #pod This class implements basic support for the
-#pod L<Avalara AvaTax|http://developer.avalara.com/api-docs/soap>
+#pod Avalara AvaTax (C<http://developer.avalara.com/api-docs/soap>)
 #pod tax engine service using SOAP. Most of its mechanics are in
 #pod L<WebService::Avalara::AvaTax::Role::Connection|WebService::Avalara::AvaTax::Role::Connection>,
 #pod with defaults for certain attributes as listed below.
 #pod
 #pod =cut
 
-use File::ShareDir::ProjectDistDir 'dist_file';
+use File::ShareDir 1.00 'module_file';
 use Moo;
 use URI;
 use XML::Compile::SOAP11;
 use XML::Compile::SOAP12;
 use XML::Compile::WSDL11;
 use namespace::clean;
-with 'WebService::Avalara::AvaTax::Role::Connection';
+with qw(
+    WebService::Avalara::AvaTax::Role::Connection
+    WebService::Avalara::AvaTax::Role::Service
+    WebService::Avalara::AvaTax::Role::Dumper
+);
 
 #pod =attr uri
 #pod
 #pod The L<URI|URI> of the WSDL file used to define the web service.
 #pod Defaults to C</tax/taxsvc.wsdl>, with the URI base either
-#pod L<https://avatax.avalara.net/> if
+#pod C<https://avatax.avalara.net/> if
 #pod L<is_production|WebService::Avalara::AvaTax::Role::Connection/is_production>
-#pod returns true, or L<https://development.avalara.net/> if it returns false.
+#pod returns true, or C<https://development.avalara.net/> if it returns false.
+#pod
+#pod Note that if
+#pod L<use_wss|WebService::Avalara::AvaTax::Role::Connection/use_wss>
+#pod is false, the alternate security WSDL file C</tax/taxsvcaltsec.wsdl>
+#pod will be used instead.
 #pod
 #pod =cut
 
 has '+uri' => (
     default => sub {
-        URI->new_abs( '/tax/taxsvc.wsdl' => 'https://'
-                . ( $_[0]->is_production ? 'avatax' : 'development' )
+        my $self = shift;
+        URI->new_abs( '/tax/taxsvc'
+                . ( $self->use_wss ? q{} : 'altsec' )
+                . '.wsdl' => 'https://'
+                . ( $self->is_production ? 'avatax' : 'development' )
                 . '.avalara.net/' );
     },
 );
@@ -62,7 +75,8 @@ has '+uri' => (
 #pod
 #pod =cut
 
-has '+port' => ( default => 'TaxSvcSoap' );
+has '+port' => ( default =>
+        sub { 'TaxSvc' . ( $_[0]->use_wss ? q{} : 'AltSec' ) . 'Soap' }, );
 
 #pod =attr service
 #pod
@@ -89,20 +103,21 @@ has '+wsdl' => (
         my $self = shift;
         my $wsdl = XML::Compile::WSDL11->new(
             $self->user_agent->get( $self->uri )->content );
-        $wsdl->addWSDL(
-            dist_file( 'WebService-Avalara-AvaTax', 'taxsvc_patch.wsdl' ) );
+        $wsdl->addWSDL( module_file( __PACKAGE__, 'taxsvc_patch.wsdl' ) );
         return $wsdl;
     },
 );
 
+#pod =for Pod::Coverage BUILDARGS
+#pod
+#pod =cut
+
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Mark Gardner ZipRecruiter cpan testmatrix url annocpan anno bugtracker rt
 cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -112,7 +127,7 @@ WebService::Avalara::AvaTax::Service::Tax - Avalara AvaTax tax engine service vi
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -127,7 +142,7 @@ version 0.018
 =head1 DESCRIPTION
 
 This class implements basic support for the
-L<Avalara AvaTax|http://developer.avalara.com/api-docs/soap>
+Avalara AvaTax (C<http://developer.avalara.com/api-docs/soap>)
 tax engine service using SOAP. Most of its mechanics are in
 L<WebService::Avalara::AvaTax::Role::Connection|WebService::Avalara::AvaTax::Role::Connection>,
 with defaults for certain attributes as listed below.
@@ -138,9 +153,14 @@ with defaults for certain attributes as listed below.
 
 The L<URI|URI> of the WSDL file used to define the web service.
 Defaults to C</tax/taxsvc.wsdl>, with the URI base either
-L<https://avatax.avalara.net/> if
+C<https://avatax.avalara.net/> if
 L<is_production|WebService::Avalara::AvaTax::Role::Connection/is_production>
-returns true, or L<https://development.avalara.net/> if it returns false.
+returns true, or C<https://development.avalara.net/> if it returns false.
+
+Note that if
+L<use_wss|WebService::Avalara::AvaTax::Role::Connection/use_wss>
+is false, the alternate security WSDL file C</tax/taxsvcaltsec.wsdl>
+will be used instead.
 
 =head2 port
 
@@ -162,6 +182,8 @@ sequences of fields. This module adds an overlay to the Avalara tax service
 WSDL file that attempts to work around these problems so that the responses
 may be successfully parsed.
 
+=for Pod::Coverage BUILDARGS
+
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -275,7 +297,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by ZipRecruiter.
+This software is copyright (c) 2016 by ZipRecruiter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
